@@ -36,7 +36,7 @@ http://talk.maemo.org/showthread.php?t=39177
 #define DESKTOP_CMD_EXEC_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE (obj, DESKTOP_CMD_EXEC_TYPE, DesktopCmdExecPrivate))
 
 #define DESKTOP_CMD_EXEC_SETTINGS_FILE "/.desktop_cmd_exec"
-#define DESKTOP_CMD_EXEC_SETTINGS_VERSION 0.6
+#define DESKTOP_CMD_EXEC_SETTINGS_VERSION 0.7
 
 //main settings window
 #define NON_GTK_RESPONSE_ADD_CMD 10
@@ -99,6 +99,8 @@ struct _DesktopCmdExecPrivate
 		guint updNeworkPolicy;
 		gdouble widthRatio;
 		gdouble heightRatio;//AP
+
+		gboolean displayTitle;
 		
 		gchar * instanceTitle;
 		gchar * instanceCmd;
@@ -191,9 +193,9 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 			if (error) {
 				//no value? assume std
 				noInstanceKeysFlag = TRUE;
-				self->priv->widthRatio = 1.0;
+				self->priv->widthRatio = 0.4;
 
-				g_warning("no widthRatio on key file, assuming 1.0");
+				g_warning("no widthRatio on key file, assuming 0.4");
 
 				g_error_free (error);
 				error = NULL;
@@ -237,6 +239,13 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 				error = NULL;
 			}
 
+			self->priv->displayTitle = g_key_file_get_boolean (keyFile, self->priv->widgetID, "displayTitle", &error);
+			if (error) {
+				self->priv->displayTitle = TRUE;
+				g_error_free (error);
+				error = NULL;
+			}
+
 			//BEGIN update policy
 			self->priv->updOnClick = g_key_file_get_boolean (keyFile, self->priv->widgetID, "updOnClick", &error);
 			if (error) {
@@ -249,7 +258,7 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 			self->priv->updOnDesktop = g_key_file_get_boolean (keyFile, self->priv->widgetID, "updOnDesktop", &error);
 			if (error) {
 
-				noInstanceKeysFlag = TRUE;
+				noInstanceKeysFlag = FALSE;
 				g_error_free (error);
 				error = NULL;
 			}
@@ -267,7 +276,7 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 			self->priv->updNeworkPolicy = (guint) g_key_file_get_integer (keyFile, self->priv->widgetID, "updNeworkPolicy", &error);
 			if (error || self->priv->updNeworkPolicy < 0 || self->priv->updNeworkPolicy > 2) {
 				//Not important; in order not to break with older key-file versions, just assume NETWORK__UNRELATED and move on..
-
+				self->priv->updNeworkPolicy = NETWORK__UNRELATED;
 				noInstanceKeysFlag = TRUE;
 
 				g_error_free (error);
@@ -289,10 +298,12 @@ void desktop_cmd_exec_read_settings ( DesktopCmdExec *self )
 	{
 		self->priv->updOnClick = TRUE;
 		self->priv->updOnDesktop = TRUE;
+		self->priv->updNeworkPolicy = NETWORK__UNRELATED;
 		self->priv->delayIndex = 0;
 		self->priv->delaySeconds = 0;
+		self->priv->displayTitle = TRUE;
 
-		self->priv->widthRatio = 1.0;
+		self->priv->widthRatio = 0.4;
 		self->priv->heightRatio = SIZE_HEIGHT_RATIO_DEFAULT;
 
 		self->priv->instanceTitle = NULL;
@@ -380,8 +391,9 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean newAll, gbo
 			self->priv->instanceCmd = g_strdup(self->priv->c_commands[0]);
 		}
 		
-		self->priv->widthRatio = 1.0;
+		self->priv->widthRatio = 0.4;
 		self->priv->heightRatio = SIZE_HEIGHT_RATIO_DEFAULT;
+		self->priv->displayTitle = TRUE;
 		self->priv->updOnClick = TRUE;
 		self->priv->updOnDesktop = TRUE;
 		self->priv->updNeworkPolicy = NETWORK__UNRELATED;
@@ -405,6 +417,7 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean newAll, gbo
 		g_key_file_set_string (keyFile, self->priv->widgetID, "instanceCmd", self->priv->instanceCmd);
 	}
 
+	g_key_file_set_boolean (keyFile, self->priv->widgetID, "displayTitle", self->priv->displayTitle);
 	g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnClick", self->priv->updOnClick);
 	g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnDesktop", self->priv->updOnDesktop);
 	g_key_file_set_integer (keyFile, self->priv->widgetID, "delayIndex", self->priv->delayIndex);
@@ -504,7 +517,11 @@ void desktop_cmd_exec_content_create (DesktopCmdExec *self)
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->contents), 0);
 // 	GtkSizeGroup *group = GTK_SIZE_GROUP (gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL));
 
-	self->priv->cmdTitle_lb = gtk_label_new ("title:");
+	if(self->priv->displayTitle)
+		self->priv->cmdTitle_lb = gtk_label_new ("title:");
+	else
+		self->priv->cmdTitle_lb = gtk_label_new ("");
+	
 	self->priv->cmdResult_lb = gtk_label_new ("result");
 
 	//gtk_label_set_line_wrap (GTK_LABEL (self->priv->cmdResult_lb), TRUE);
@@ -593,7 +610,10 @@ gboolean desktop_cmd_exec_update_content (DesktopCmdExec *self)
 		return 0;
 	}
 
-	gtk_label_set_text (GTK_LABEL (self->priv->cmdTitle_lb), self->priv->instanceTitle);
+	if(self->priv->displayTitle)
+		gtk_label_set_text (GTK_LABEL (self->priv->cmdTitle_lb), self->priv->instanceTitle);
+	else
+		gtk_label_set_text (GTK_LABEL (self->priv->cmdTitle_lb), "");
 
 	fp = popen (self->priv->instanceCmd, "r");
 
@@ -836,7 +856,8 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		{
 			hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), self->priv->c_titles[i]);
 			if(g_strcmp0(self->priv->c_titles[i],self->priv->instanceTitle) == 0)
-				hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, i);
+				if(g_strcmp0(self->priv->c_commands[i],self->priv->instanceCmd) == 0)
+					hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, i);
 		}
 		
 		GtkWidget * cmdSelector = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
@@ -893,7 +914,11 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		gtk_box_pack_start (GTK_BOX (heightBox), heightSelect, TRUE, TRUE, 0);//AP
 		
 		gtk_container_add (GTK_CONTAINER (content_area), heightBox);//AP
-		
+
+		GtkWidget *checkDisplayTitle = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+		gtk_button_set_label (GTK_BUTTON (checkDisplayTitle), "Display Title");
+		gtk_container_add (GTK_CONTAINER (content_area), checkDisplayTitle);
+		hildon_check_button_set_active (HILDON_CHECK_BUTTON (checkDisplayTitle), self->priv->displayTitle);
 		//END
 
 		//BEGIN Update Policy
@@ -976,6 +1001,8 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 // 			gtk_window_resize (GTK_WINDOW (self), (int)(SIZE_WIDTH_ALL*self->priv->widthRatio), SIZE_HEIGHT_LINE);
 			gtk_widget_set_size_request (GTK_WIDGET (self), (int)(SIZE_WIDTH_ALL*self->priv->widthRatio), (int)(SIZE_HEIGHT_LINE*self->priv->heightRatio));//AP
 			gtk_window_resize (GTK_WINDOW (self), (int)(SIZE_WIDTH_ALL*self->priv->widthRatio), (int)(SIZE_HEIGHT_LINE*self->priv->heightRatio));//AP
+
+			self->priv->displayTitle = hildon_check_button_get_active (HILDON_CHECK_BUTTON (checkDisplayTitle));
 			
 			self->priv->updOnClick = hildon_check_button_get_active (HILDON_CHECK_BUTTON (checkBtClick));
 			self->priv->updOnDesktop = hildon_check_button_get_active (HILDON_CHECK_BUTTON (checkBtDesktop));
@@ -1073,9 +1100,15 @@ void desktop_cmd_exec_edit_add_dialog ( DesktopCmdExec *self, gboolean new, gint
 
 	gtk_widget_show_all (dialog);
 	int dialogRunResponse = gtk_dialog_run (GTK_DIALOG (dialog));
+	int i=0;
 	switch(dialogRunResponse)
 	{
 		case GTK_RESPONSE_ACCEPT:
+			if(g_strcmp0((gchar *)"",hildon_entry_get_text (HILDON_ENTRY (titleEntry))) == 0)
+			{
+				hildon_entry_set_text(HILDON_ENTRY (titleEntry), "[No Title]");
+			}
+			
 			if(new)
 			{
 				AddCommand(self, g_strdup(hildon_entry_get_text (HILDON_ENTRY (titleEntry))), g_strdup(hildon_entry_get_text (HILDON_ENTRY (commandEntry))));
